@@ -1,11 +1,12 @@
+from __future__ import print_function
 import logging
 
 from designateclient.v2 import client
 from designateclient import exceptions
 from designateclient import shell
 
-from keystoneclient.auth.identity import generic
-from keystoneclient import session as keystone_session
+from keystoneauth1.identity import generic
+from keystoneauth1 import session as keystone_session
 
 
 logging.basicConfig(level='DEBUG')
@@ -19,7 +20,9 @@ auth = generic.Password(
     auth_url=shell.env('OS_AUTH_URL'),
     username=shell.env('OS_USERNAME'),
     password=shell.env('OS_PASSWORD'),
-    tenant_name=shell.env('OS_TENANT_NAME'))
+    project_name=shell.env('OS_PROJECT_NAME'),
+    project_domain_id='default',
+    user_domain_id='default')
 
 session = keystone_session.Session(auth=auth)
 
@@ -33,7 +36,7 @@ except exceptions.RemoteError:
 
 print("Recordset list...")
 for rs in client.recordsets.list(zone['id']):
-    print rs
+    print(rs)
 
 # Here's an example of just passing "www" as the record name vs "www.i.io."
 records = ["10.0.0.1"]
